import {
  csv,
  select,
  json,
  geoPath,
  geoAlbersUsa,
  zoom,
  event,
  scaleOrdinal,
  schemeCategory10
} from 'd3';


import { feature } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData';
import {colorLegend} from './colorLegend'

const colorScale = scaleOrdinal(schemeCategory10);

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const projection = geoAlbersUsa();
const pathGenerator = geoPath().projection(projection);


const g = svg.append('g');

svg.call(zoom().on('zoom', ()=>{
  g.attr('transform', event.transform)
}));

Promise.all([
    csv('stateid.csv'), 
    json('https://gist.githubusercontent.com/mbostock/4090846/raw/d534aba169207548a8a3d670c9c2cc719ff05c47/us.json'), 
    csv('https://vizhub.com/NTCHANG1289/datasets/FastFoodRestaurants_New.csv')])
  .then(([stateid, json, datasetin]) => {
    
    const rowByID = stateid.reduce((accumulator, d) => {
      accumulator[d.sid] = d;
      return accumulator;
    }, {});
    
    const statespv = feature(json, json.objects.states);
    
    statespv.features.forEach(d => {
      Object.assign(d.properties, rowByID[d.id]);
    });
     g.selectAll('path').data(statespv.features)
       .enter().append('path')
         .attr('class', 'states')
         .attr('d', pathGenerator)
  			 .attr('fill', d =>colorScale(console.log(d.properties.state)))
   	  .append('title')
   		  .text(d => d.properties.Province);
//		});

var data2 = datasetin.filter(d => 
   		d.longitude < -50 & d.latitude  > 23 |
      d.province =="HI"); 
  
    const realpos = data2.map( d => 
            [+d.longitude, +d.latitude, d.name]);
     g.selectAll("circle").data(realpos)
       .enter().append("circle")
         .attr("cx", d =>projection(d)[0])
         .attr("cy", d =>projection(d)[1])
         .attr("r", "2.5")
         .attr("fill", d => colorScale(d[2]));
       
     const title_pos = 50;
       g.append('text')
       .attr("class", 'mytitle')
       .attr('font-size', title_pos*0.8)
       .attr('x', width/2)
       .attr('y', title_pos)
       .text('American fastfood map')
       g.append('text')
       .attr('font-size', 350)
       .attr('x', 950)
       .attr('y', 300)
       .text('~(^ O ^)~')
  });








